==> 0.0.8.tar.gz: lib/widgets/listview/ylvheaders/ylvappbarheader.dart <==
import 'package:yflutter_widgets/widgets/listview/ylvproviders/contractedbarprovider.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class YLVAppBarHeader extends StatefulWidget {
  YLVAppBarHeader({
    @required this.insideWidget,
    this.title = "",
    this.headerColor = Colors.white,
    this.leftBarItem,
    this.rightBarItems,
    this.headerHeight = 150,
    this.titleColor = Colors.black,
    this.contractedTitleColor = Colors.white,
    this.titleFontSize = 18,
  });


  final Widget insideWidget;
  final String title;
  final double titleFontSize;
  final Color titleColor;
  final Color contractedTitleColor;
  final Color headerColor;
  final double headerHeight;
  final Widget leftBarItem;
  final List<Widget> rightBarItems;


  @override
  _YLVAppBarHeaderState createState() => _YLVAppBarHeaderState();
}

class _YLVAppBarHeaderState extends State<YLVAppBarHeader> {
  @override
  Widget build(BuildContext context) {
    return SliverAppBar(
      backgroundColor: widget.headerColor,
      pinned: true,
      snap: false,
      floating: false,
      leading: widget.leftBarItem,
      actions: widget.rightBarItems,
      centerTitle: true,
      title: Consumer<ContractedBarProvider> (
        builder: (BuildContext context, ContractedBarProvider contractedBarProvider, Widget child) {
          return Text(
            widget.title,
            style: TextStyle(
            color: contractedBarProvider.isContracted ? widget.contractedTitleColor : widget.titleColor,
            fontSize: widget.titleFontSize
            ),
          );
        },
      ) ,
      expandedHeight: widget.headerHeight,
      flexibleSpace: FlexibleSpaceBar(
        background: widget.insideWidget
      ),
    );
  }
}

==> 0.2.5.tar.gz: lib/widgets/listview/ylvheaders/ylvappbarheader.dart <==
import 'package:yflutter_widgets/widgets/listview/ylvproviders/contractedbarprovider.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class YLVAppBarHeader extends StatefulWidget {
  YLVAppBarHeader({
    @required this.insideWidget,
    this.title = "",
    this.headerColor = Colors.white,
    this.leftBarItem,
    this.rightBarItems,
    this.headerHeight = 150,
    this.titleColor = Colors.black,
    this.contractedTitleColor = Colors.white,
    this.titleFontSize = 18,
    this.elevation = 10,
    this.isForcedElevated = false,
  });


  final Widget insideWidget;
  final String title;
  final double titleFontSize;
  final Color titleColor;
  final double elevation;
  final bool isForcedElevated;
  final Color contractedTitleColor;
  final Color headerColor;
  final double headerHeight;
  final Widget leftBarItem;
  final List<Widget> rightBarItems;


  @override
  _YLVAppBarHeaderState createState() => _YLVAppBarHeaderState();
}

class _YLVAppBarHeaderState extends State<YLVAppBarHeader> {
  @override
  Widget build(BuildContext context) {
    return SliverAppBar(
      brightness: Brightness.light,
      backgroundColor: widget.headerColor,
      pinned: true,
      snap: false,
      floating: false,
      leading: widget.leftBarItem,
      actions: widget.rightBarItems,
      centerTitle: true,
      elevation: widget.elevation,
      forceElevated: widget.isForcedElevated,
      title: Consumer<ContractedBarProvider> (
        builder: (BuildContext context, ContractedBarProvider contractedBarProvider, Widget child) {
          return Text(
            widget.title,
            style: TextStyle(
            color: contractedBarProvider.isContracted ? widget.contractedTitleColor : widget.titleColor,
            fontSize: widget.titleFontSize
            ),
          );
        },
      ) ,
      expandedHeight: widget.headerHeight,
      flexibleSpace: FlexibleSpaceBar(
        background: widget.insideWidget,
      ),
    );
  }
}
